import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RepositoryFileConfig extends cdktf.TerraformMetaArguments {
    /**
    * The branch name, defaults to "main"
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository_file#branch RepositoryFile#branch}
    */
    readonly branch?: string;
    /**
    * The commit author name, defaults to the authenticated user's name
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository_file#commit_author RepositoryFile#commit_author}
    */
    readonly commitAuthor?: string;
    /**
    * The commit author email address, defaults to the authenticated user's email address
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository_file#commit_email RepositoryFile#commit_email}
    */
    readonly commitEmail?: string;
    /**
    * The commit message when creating or updating the file
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository_file#commit_message RepositoryFile#commit_message}
    */
    readonly commitMessage?: string;
    /**
    * The file's content
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository_file#content RepositoryFile#content}
    */
    readonly content: string;
    /**
    * The file path to manage
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository_file#file RepositoryFile#file}
    */
    readonly file: string;
    /**
    * Enable overwriting existing files, defaults to "false"
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository_file#overwrite_on_create RepositoryFile#overwrite_on_create}
    */
    readonly overwriteOnCreate?: boolean | cdktf.IResolvable;
    /**
    * The repository name
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository_file#repository RepositoryFile#repository}
    */
    readonly repository: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/github/r/repository_file github_repository_file}
*/
export declare class RepositoryFile extends cdktf.TerraformResource {
    static readonly tfResourceType = "github_repository_file";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/github/r/repository_file github_repository_file} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RepositoryFileConfig
    */
    constructor(scope: Construct, id: string, config: RepositoryFileConfig);
    private _branch?;
    get branch(): string;
    set branch(value: string);
    resetBranch(): void;
    get branchInput(): string | undefined;
    private _commitAuthor?;
    get commitAuthor(): string;
    set commitAuthor(value: string);
    resetCommitAuthor(): void;
    get commitAuthorInput(): string | undefined;
    private _commitEmail?;
    get commitEmail(): string;
    set commitEmail(value: string);
    resetCommitEmail(): void;
    get commitEmailInput(): string | undefined;
    private _commitMessage?;
    get commitMessage(): string;
    set commitMessage(value: string);
    resetCommitMessage(): void;
    get commitMessageInput(): string | undefined;
    get commitSha(): string;
    private _content?;
    get content(): string;
    set content(value: string);
    get contentInput(): string | undefined;
    private _file?;
    get file(): string;
    set file(value: string);
    get fileInput(): string | undefined;
    get id(): string;
    private _overwriteOnCreate?;
    get overwriteOnCreate(): boolean | cdktf.IResolvable;
    set overwriteOnCreate(value: boolean | cdktf.IResolvable);
    resetOverwriteOnCreate(): void;
    get overwriteOnCreateInput(): boolean | cdktf.IResolvable | undefined;
    private _repository?;
    get repository(): string;
    set repository(value: string);
    get repositoryInput(): string | undefined;
    get sha(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=repository-file.d.ts.map